@@ -1,17 +1,17 @@
 //! This crate provides a simple `Bytes` struct that stores a number
 //! and displays it in as the appropriate multiple of a power of  1000 bytes,
 //! i.e. in Megabytes, Gigabyte, etc. for human readability.
-//! 
+//!
 //! Example:
-//! 
-//! ```
+//!
+//! ```rust
 //! let b = Bytes(5247 as u16);
-//! assert_eq("5.25 MB", b);
+//! println!("{}", b)  //  Prints "5.25 KB"
 //! ```
-//! 
+//!
 //! The number is stored internally in the same type as was provided to initialize
 //! the struct: `u16` in this example.
-//! 
+//!
 
 mod test;
 
@@ -52,7 +52,7 @@ where
         if b < BASE {
             return write!(f, "{} B", self.0);
         }
-        // Megabytes
+        // Kilobytes
         // We subtract the number of bytes needed to get to the point where the value
         // (rounded at the second decimal) jumps to the next power of 10
         // (e.g. 999.99 MB -> 1.00 GB at 1,000,000 - 5 = 999,995)
@@ -64,11 +64,20 @@ where
             // value in f64 and risk overflow (u64 does not implement Into<f64>).
             let mut result: f64 = quotient as f64 + remainder as f64 / divisor as f64;
             result = (result * 100.0).round() / 100.0;
+            return write!(f, "{:.2} KB", result);
+        }
+        // Megabytes
+        else if b < BASE.pow(3) - 5 * BASE {
+            let divisor = BASE.pow(2);
+            let quotient = b / divisor;
+            let remainder = b % divisor;
+            let mut result: f64 = quotient as f64 + remainder as f64 / divisor as f64;
+            result = (result * 100.0).round() / 100.0;
             return write!(f, "{:.2} MB", result);
         }
         // Gigabytes
-        else if b < BASE.pow(3) - 5 * BASE {
-            let divisor = BASE.pow(2);
+        else if b < BASE.pow(4) - 5 * BASE.pow(2) {
+            let divisor = BASE.pow(3);
             let quotient = b / divisor;
             let remainder = b % divisor;
             let mut result: f64 = quotient as f64 + remainder as f64 / divisor as f64;
@@ -76,8 +85,8 @@ where
             return write!(f, "{:.2} GB", result);
         }
         // Terabytes
-        else if b < BASE.pow(4) - 5 * BASE.pow(2) {
-            let divisor = BASE.pow(3);
+        else if b < BASE.pow(5) - 5 * BASE.pow(3) {
+            let divisor = BASE.pow(4);
             let quotient = b / divisor;
             let remainder = b % divisor;
             let mut result: f64 = quotient as f64 + remainder as f64 / divisor as f64;
@@ -85,23 +94,14 @@ where
             return write!(f, "{:.2} TB", result);
         }
         // Petabytes
-        else if b < BASE.pow(5) - 5 * BASE.pow(3) {
-            let divisor = BASE.pow(4);
-            let quotient = b / divisor;
-            let remainder = b % divisor;
-            let mut result: f64 = quotient as f64 + remainder as f64 / divisor as f64;
-            result = (result * 100.0).round() / 100.0;
-            return write!(f, "{:.2} PB", result);
-        }
-        // Exabytes
-        // Anything larger will be displayed as exabytes
+        // Anything larger will be displayed as petabytes
         else {
             let divisor = BASE.pow(5);
             let quotient = b / divisor;
             let remainder = b % divisor;
             let mut result: f64 = quotient as f64 + remainder as f64 / divisor as f64;
             result = (result * 100.0).round() / 100.0;
-            return write!(f, "{:.2} EB", result);
+            return write!(f, "{:.2} PB", result);
         }
     }
 }
